<?php

/**
 * @file 
 * Delta UI functionality
 */

/**
 * @todo
 */
function delta_ui_layouts_page($theme_name = FALSE) {
  $themes = list_themes();
  $header = array(t('Title'), t('Machine name'), array('data' => t('Operations'), 'colspan' => '3'));
  
  $form['themes'] = array(
    '#type' => 'vertical_tabs',
    '#tree' => TRUE,
    '#weight' => -10,
  );
  
  foreach ($themes as $theme => $info) {
    if ($info->status) {
      $form['themes'][$theme] = array(
        '#type' => 'fieldset',
        '#title' => $info->info['name'],
      );
      
      $form['themes'][$theme]['content'] = array(
        '#theme' => 'table',
        '#header' => $header,
        '#rows' => array(),
        '#empty' => t('There are no theme settings templates availabe for %theme. <a href="@link" title="Add a layout">Add a layout</a>.', array('%theme' => $themes[$theme]->info['name'], '@link' => url('admin/appearance/delta/layouts/add'))),      
      );
    }
  }
  
  foreach (delta_layouts() as $layout => $info) {
    if (isset($themes[$info->theme]) && $themes[$info->theme]->status) {
      $form['themes'][$info->theme]['content']['#rows'][] = array(
        'title' => $info->name,
        'name' => $info->machine_name,
        'edit' => l(t('Edit'), 'admin/appearance/delta/layouts/edit/' . $info->machine_name),
        'configure' => l(t('Configure'), 'admin/appearance/delta/layouts/configure/' . $info->machine_name),
        'delete' => l(t('Delete'), 'admin/appearance/delta/layouts/delete/' . $info->machine_name),
      );     
    }
  }
  
  return $form;
}

/**
 * @todo
 */
function delta_ui_layout_edit($form, &$form_state, $layout = NULL) {
  if(isset($layout)) {
    drupal_set_title(t('Edit Delta Layout'));
  }
  else {
    drupal_set_title(t('Add Delta Layout'));
  }

  $form['old'] = array(
    '#type' => 'value',
    '#value' => $layout,
  );
  
  $form['delta'] = array(
    '#type' => 'fieldset',
    '#title' => t('Template settings'),
  );
  
  $form['delta']['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Title'),
    '#description' => t('The human readable name for this template.'),
    '#default_value' => isset($layout) ? $layout->name : (isset($form_state['values']['name']) ? $form_state['values']['name'] : ''),
    '#required' => TRUE,
  );

  $form['delta']['machine_name'] = array(
    '#type' => 'machine_name',
    '#title' => t('Machine name'),
    '#description' => t('A unique machine-readable name for this theme settings template. It must only contain lowercase letters, numbers, and hyphens.'),
    '#default_value' => isset($layout) ? $layout->machine_name : (isset($form_state['values']['machine_name']) ? $form_state['values']['machine_name'] : ''),
    '#required' => TRUE,
    '#maxlength' => 32,
    '#disabled' => isset($layout),
    '#machine_name' => array(
      'source' => array('delta', 'name'),
      'exists' => 'delta_load',
      'replace_pattern' => '[^a-z0-9-]+', 
      'replace' => '-',
    ),
  );
  
  $form['delta']['theme'] = array(
    '#type' => 'select',
    '#title' => t('Theme'),
    '#required' => TRUE,
    '#description' => t('The theme that you want to create this template for.'),
    '#default_value' => isset($layout) ? $layout->theme : (isset($form_state['values']['theme']) ? $form_state['values']['theme'] : ''),
    '#options' => delta_theme_options(),
    '#disabled' => isset($layout),
  );
  
  $form['delta']['mode'] = array(
    '#type' => 'radios',
    '#title' => t('Operation mode'),
    '#description' => t('This setting controls the way that settings are being stored and overriden.'),
    '#default_value' => isset($layout) ? $layout->mode : (isset($form_state['values']['mode']) ? $form_state['values']['mode'] : DELTA_PRESERVE),
    '#options' => array(
      DELTA_PRESERVE => t('Only override different values'),
      DELTA_OVERRIDE => t('Override all values'),
    ),
  );
  
  $form['delta']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
    '#submit' => array('delta_ui_layout_edit_submit'),
  );
  
  return $form;
}

/**
 * @todo
 */
function delta_ui_layout_edit_submit($form, &$form_state) {
  $values = $form_state['values'];
  $themes = list_themes();
  $settings = delta_settings($values['machine_name'], $values['theme']);
  $original = isset($GLOBALS['conf']['theme_' . $values['theme'] . '_settings']) ? $GLOBALS['conf']['theme_' . $values['theme'] . '_settings'] : array();
  
  $values['settings'] = delta_settings_prepare($settings, $original, $values['mode']);

  delta_save($values);
  
  drupal_set_message(t('The custom theme settings layout <strong>@name</strong> has been saved for %theme.', array('@name' => $values['name'], '%theme' => $themes[$values['theme']]->info['name'])));
  drupal_set_message(t('You may now configure the <strong>@name</strong> theme settings layout.', array('@name' => $values['name'])));
  
  drupal_goto('admin/appearance/delta/layouts/configure/' . $values['machine_name']);
}

/**
 * @todo
 */
function delta_ui_layout_configure($form, &$form_state, $layout) {
  module_load_include('inc', 'system', 'system.admin');
  delta_inject_settings($layout->machine_name, $layout->theme);

  $form_state['delta'] = $layout->machine_name;
  $form_state['delta_mode'] = $layout->mode;
  $form_state['build_info']['args'][0] = $layout->theme;
  
  $form = system_theme_settings($form, $form_state, $layout->theme); 

  $system = array_search('system_theme_settings_submit', $form['#submit']);
  $form['#submit'][$system] = 'delta_ui_layout_configure_submit';
  
  return $form;
}

/**
 * @todo
 */
function delta_ui_layout_configure_submit($form, &$form_state) {
  global $conf;
  
  $theme = $form_state['build_info']['args'][0];
  $key = $form_state['values']['var'];
  $conf = variable_initialize();
  $backup = variable_get($key);
  
  system_theme_settings_submit($form, $form_state);
  delta_save_settings($form_state['delta'], variable_get($key), $backup, $form_state['delta_mode']);
    
  variable_set($key, $backup);
}

/**
 * @todo
 */
function delta_ui_layout_delete_confirm($form, &$form_state, $layout = NULL) {
  $form_state['layout'] = $layout;
  
  return confirm_form($form,
    t('Are you sure you want to delete this template?'),
    'admin/appearance/delta',
    t('This action cannot be undone.'),
    t('Delete'),
    t('Cancel')
  );
}

/**
 * @todo
 */
function delta_ui_layout_delete_confirm_submit($form, &$form_state) {
  if ($form_state['values']['confirm']) {
    $layout = $form_state['layout'];
    
    delta_delete($layout->machine_name);    
    drupal_set_message(t('The layout %name has been deleted.', array('%name' => $layout->name)));
  }

  $form_state['redirect'] = 'admin/appearance/delta';
}